==> jc-1.4.0.tar.gz: java/net/ContentHandler.c <==
// public abstract class java.net.ContentHandler

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2441695b7a69eb12 java_lang_VMClass
// @dep_class 4d87ebfc52d36524 java_net_ContentHandler
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMClass
// @dep_header java_net_ContentHandler
// @dep_header java_net_URLConnection

#include "jc_defs.h"

#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMClass.h"
#include "java/net/ContentHandler.h"
#include "java/net/URLConnection.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_java_net_ContentHandler$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_net_ContentHandler$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_net_ContentHandler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_ContentHandler$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_ContentHandler, _init$52f4ad9f2989aeee);

void
_jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_net_ContentHandler$object *this)
{
	struct _jc_java_net_ContentHandler$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.lang.Object getContent(java.net.URLConnection) throws java.io.IOException
//

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$getContent$677478719bf4670d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_net_ContentHandler$exceptions$getContent$677478719bf4670d[] = {
	&_jc_java_io_IOException$type
};

static _jc_type *const _jc_java_net_ContentHandler$param_types$getContent$677478719bf4670d[] = {
	&_jc_java_net_URLConnection$type
};

_jc_method _jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d = {
	.name=			"getContent",
	.signature=		"(Ljava/net/URLConnection;)Ljava/lang/Object;",
	.class=			&_jc_java_net_ContentHandler$type,
	.param_types=		&_jc_java_net_ContentHandler$param_types$getContent$677478719bf4670d,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$getContent$677478719bf4670d,
	.signature_hash=	_JC_JLONG(0x677478719bf4670d),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_net_ContentHandler$method$getContent$677478719bf4670d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_ContentHandler$vtable, java_net_ContentHandler.getContent$677478719bf4670d) / sizeof(void *),
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_net_ContentHandler$exceptions$getContent$677478719bf4670d,
};

_jc_java_lang_Object$object *
_jc_java_net_ContentHandler$method$getContent$677478719bf4670d(_jc_env *const env, _jc_java_net_ContentHandler$object *this, _jc_java_net_URLConnection$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d);
}

//
// public java.lang.Object getContent(java.net.URLConnection, java.lang.Class[]) throws java.io.IOException
//

static _jc_linenum _jc_java_net_ContentHandler$linenum_table$getContent$ec7ec17441ac55e5[];

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$getContent$ec7ec17441ac55e5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_net_ContentHandler$exceptions$getContent$ec7ec17441ac55e5[] = {
	&_jc_java_io_IOException$type
};

static _jc_type *const _jc_java_net_ContentHandler$param_types$getContent$ec7ec17441ac55e5[] = {
	&_jc_java_net_URLConnection$type,
	&_jc_java_lang_Class$array$type
};

_jc_method _jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5 = {
	.name=			"getContent",
	.signature=		"(Ljava/net/URLConnection;[Ljava/lang/Class;)Ljava/lang/Object;",
	.class=			&_jc_java_net_ContentHandler$type,
	.param_types=		&_jc_java_net_ContentHandler$param_types$getContent$ec7ec17441ac55e5,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$getContent$ec7ec17441ac55e5,
	.signature_hash=	_JC_JLONG(0xec7ec17441ac55e5),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_ContentHandler$vtable, java_net_ContentHandler.getContent$ec7ec17441ac55e5) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_net_ContentHandler$exceptions$getContent$ec7ec17441ac55e5,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	6,
	      .table=	_jc_java_net_ContentHandler$linenum_table$getContent$ec7ec17441ac55e5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_ContentHandler, getContent$ec7ec17441ac55e5);

_jc_java_lang_Object$object *
_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5(_jc_env *const env, _jc_java_net_ContentHandler$object *this, _jc_java_net_URLConnection$object *param0, _jc_object_array *param1)
{
	jint i0;
	jint i1;
	struct _jc_java_net_ContentHandler$object *r0;
	struct _jc_java_net_URLConnection$object *r1;
	_jc_object_array *r2;
	struct _jc_java_lang_Object$object *r3;
	struct _jc_java_lang_Class$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(116);				// 0
	r3 = _JC_INVOKE_VIRTUAL(env, java_net_ContentHandler, getContent$677478719bf4670d, r0, r1);
	_JC_LINE_NUMBER(118);				// 1
	i0 = 0;
	goto label2;

label0:
	_JC_LINE_NUMBER(120);				// 2
	r4 = _JC_REF_ELEMENT(env, r2, i0, 0, 1);
	_JC_EXPLICIT_NULL_CHECK(env, r4);
	z1 = _JC_INVOKE_STATIC(env, java_lang_VMClass, isInstance$ede5df617b373545, 0, r4, r3);
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(121);				// 3
	return r3;

label1:
	_JC_LINE_NUMBER(118);				// 4
	i0 = i0 + 1;

label2:
	i1 = _JC_ARRAY_LENGTH(env, r2);
	if (i0 < i1) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	_JC_LINE_NUMBER(124);				// 5
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_ContentHandler$methods[] = {
	&_jc_java_net_ContentHandler$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d,
	&_jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_ContentHandler$instanceof_hash_bucket_36[] = {
	&_jc_java_net_ContentHandler$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_ContentHandler$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_ContentHandler$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[36]=	_jc_java_net_ContentHandler$instanceof_hash_bucket_36,
	[113]=	_jc_java_net_ContentHandler$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_ContentHandler$class_depends[] = {
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/VMClass",	_JC_JLONG(0x2441695b7a69eb12) },
	{ "java/net/URLConnection",	_JC_JLONG(0x1042c111741aa488) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_ContentHandler$vtype _jc_java_net_ContentHandler$type = {
    .type= {
	.name=			"java/net/ContentHandler",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x4d87ebfc52d36524),
		.source_file=		"ContentHandler.java",
		.instance_size=		sizeof(_jc_java_net_ContentHandler$refs) + sizeof(_jc_java_net_ContentHandler$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_net_ContentHandler$methods) / sizeof(*_jc_java_net_ContentHandler$methods),
		.methods=		_jc_java_net_ContentHandler$methods,
		.instanceof_hash_table=	_jc_java_net_ContentHandler$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_ContentHandler$class_depends) / sizeof(*_jc_java_net_ContentHandler$class_depends),
		.class_depends=		_jc_java_net_ContentHandler$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_ContentHandler= {
	    .getContent$677478719bf4670d=
		&_jc_java_net_ContentHandler$method$getContent$677478719bf4670d,
	    .getContent$ec7ec17441ac55e5=
		&_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5,
	},
    }
};

==> jc-1.4.5.tar.gz: java/net/ContentHandler.c <==
// public abstract class java.net.ContentHandler

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 238a2c0aafd74314 java_lang_VMClass
// @dep_class 4d87ebfc52d36524 java_net_ContentHandler
// @dep_class 1042c111741aa488 java_net_URLConnection

// header file dependencies
// @dep_header java_io_IOException
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_VMClass
// @dep_header java_net_ContentHandler
// @dep_header java_net_URLConnection

#include "jc_defs.h"

#include "java/io/IOException.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/VMClass.h"
#include "java/net/ContentHandler.h"
#include "java/net/URLConnection.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_java_net_ContentHandler$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_net_ContentHandler$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_net_ContentHandler$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_net_ContentHandler$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_ContentHandler, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_net_ContentHandler$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_net_ContentHandler$object *this)
{
	struct _jc_java_net_ContentHandler$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(71);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public abstract java.lang.Object getContent(java.net.URLConnection) throws java.io.IOException
//

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$getContent$677478719bf4670d[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_net_ContentHandler$exceptions$getContent$677478719bf4670d[] = {
	&_jc_java_io_IOException$type
};

static _jc_type *const _jc_java_net_ContentHandler$param_types$getContent$677478719bf4670d[] = {
	&_jc_java_net_URLConnection$type
};

_jc_method _jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d = {
	.name=			"getContent",
	.signature=		"(Ljava/net/URLConnection;)Ljava/lang/Object;",
	.class=			&_jc_java_net_ContentHandler$type,
	.param_types=		&_jc_java_net_ContentHandler$param_types$getContent$677478719bf4670d,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$getContent$677478719bf4670d,
	.signature_hash=	_JC_JLONG(0x677478719bf4670d),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.function=		&_jc_java_net_ContentHandler$method$getContent$677478719bf4670d,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_ContentHandler$vtable, java_net_ContentHandler.getContent$677478719bf4670d) / sizeof(void *),
	.num_parameters=	1,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_net_ContentHandler$exceptions$getContent$677478719bf4670d,
};

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_net_ContentHandler$method$getContent$677478719bf4670d(_jc_env *const env, _jc_java_net_ContentHandler$object *this, _jc_java_net_URLConnection$object *param0)
{
	_JC_ABSTRACT_METHOD(env, &_jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d);
}

//
// public java.lang.Object getContent(java.net.URLConnection, java.lang.Class[]) throws java.io.IOException
//

static _jc_linenum _jc_java_net_ContentHandler$linenum_table$getContent$ec7ec17441ac55e5[];

static const unsigned char _jc_java_net_ContentHandler$param_ptypes$getContent$ec7ec17441ac55e5[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_net_ContentHandler$exceptions$getContent$ec7ec17441ac55e5[] = {
	&_jc_java_io_IOException$type
};

static _jc_type *const _jc_java_net_ContentHandler$param_types$getContent$ec7ec17441ac55e5[] = {
	&_jc_java_net_URLConnection$type,
	&_jc_java_lang_Class$array$type
};

_jc_method _jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5 = {
	.name=			"getContent",
	.signature=		"(Ljava/net/URLConnection;[Ljava/lang/Class;)Ljava/lang/Object;",
	.class=			&_jc_java_net_ContentHandler$type,
	.param_types=		&_jc_java_net_ContentHandler$param_types$getContent$ec7ec17441ac55e5,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_net_ContentHandler$param_ptypes$getContent$ec7ec17441ac55e5,
	.signature_hash=	_JC_JLONG(0xec7ec17441ac55e5),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_net_ContentHandler$vtable, java_net_ContentHandler.getContent$ec7ec17441ac55e5) / sizeof(void *),
	.num_parameters=	2,
	.num_exceptions=	1,
	.exceptions=		&_jc_java_net_ContentHandler$exceptions$getContent$ec7ec17441ac55e5,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	6,
	      .table=	_jc_java_net_ContentHandler$linenum_table$getContent$ec7ec17441ac55e5
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_net_ContentHandler, getContent$ec7ec17441ac55e5);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5(_jc_env *const env, _jc_java_net_ContentHandler$object *this, _jc_java_net_URLConnection$object *param0, _jc_object_array *param1)
{
	jint i0;
	jint i1;
	struct _jc_java_net_ContentHandler$object *r0;
	struct _jc_java_net_URLConnection$object *r1;
	_jc_object_array *r2;
	struct _jc_java_lang_Object$object *r3;
	struct _jc_java_lang_Class$object *r4;
	jboolean z1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(116);				// 0
	r3 = _JC_INVOKE_VIRTUAL(env, java_net_ContentHandler, getContent$677478719bf4670d, r0, r1);
	_JC_LINE_NUMBER(118);				// 1
	i0 = 0;
	goto label2;

label0:
	_JC_LINE_NUMBER(120);				// 2
	r4 = _JC_REF_ELEMENT(env, r2, i0, 0, 1);
	_JC_EXPLICIT_NULL_CHECK(env, r4);
	z1 = _JC_INVOKE_STATIC(env, java_lang_VMClass, isInstance$ede5df617b373545, 0, r4, r3);
	if (z1 == 0)
		goto label1;
	_JC_LINE_NUMBER(121);				// 3
	return r3;

label1:
	_JC_LINE_NUMBER(118);				// 4
	i0 = i0 + 1;

label2:
	i1 = _JC_ARRAY_LENGTH(env, r2);
	if (i0 < i1) {
		_JC_PERIODIC_CHECK(env);
		goto label0;
	}
	_JC_LINE_NUMBER(124);				// 5
	return _JC_NULL;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_net_ContentHandler$methods[] = {
	&_jc_java_net_ContentHandler$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_net_ContentHandler$method_info$getContent$677478719bf4670d,
	&_jc_java_net_ContentHandler$method_info$getContent$ec7ec17441ac55e5
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_net_ContentHandler$instanceof_hash_bucket_36[] = {
	&_jc_java_net_ContentHandler$type,
	_JC_NULL
};
static _jc_type *const _jc_java_net_ContentHandler$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_net_ContentHandler$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[36]=	_jc_java_net_ContentHandler$instanceof_hash_bucket_36,
	[101]=	_jc_java_net_ContentHandler$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_net_ContentHandler$class_depends[] = {
	{ "java/io/IOException",	_JC_JLONG(0x4e0a56550c69d57c) },
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/VMClass",	_JC_JLONG(0x238a2c0aafd74314) },
	{ "java/net/URLConnection",	_JC_JLONG(0x1042c111741aa488) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_net_ContentHandler$vtype _jc_java_net_ContentHandler$type = {
    .type= {
	.name=			"java/net/ContentHandler",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_ABSTRACT,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x4d87ebfc52d36524),
		.source_file=		"ContentHandler.java",
		.instance_size=		sizeof(_jc_java_net_ContentHandler$refs) + sizeof(_jc_java_net_ContentHandler$object),
		.num_virtual_refs=	0,
		.num_methods=		sizeof(_jc_java_net_ContentHandler$methods) / sizeof(*_jc_java_net_ContentHandler$methods),
		.methods=		_jc_java_net_ContentHandler$methods,
		.instanceof_hash_table=	_jc_java_net_ContentHandler$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_net_ContentHandler$class_depends) / sizeof(*_jc_java_net_ContentHandler$class_depends),
		.class_depends=		_jc_java_net_ContentHandler$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_net_ContentHandler= {
	    .getContent$677478719bf4670d=
		&_jc_java_net_ContentHandler$method$getContent$677478719bf4670d,
	    .getContent$ec7ec17441ac55e5=
		&_jc_java_net_ContentHandler$method$getContent$ec7ec17441ac55e5,
	},
    }
};
